/************************************************************************
	filename: 	CEGUIMoveScaleBoxProperties.h
	created:	10/7/2004
	author:		Paul D Turner

	purpose:	Interface to properties for FrameWIndow class
*************************************************************************/
/*************************************************************************
    Crazy Eddie's GUI System (http://www.cegui.org.uk)
    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*************************************************************************/
#ifndef _CEGUIMoveScaleBoxProperties_h_
#define _CEGUIMoveScaleBoxProperties_h_

#include "CEGUIProperty.h"


// Start of CEGUI namespace section
namespace CEGUI
{

// Start of MoveScaleBoxProperties namespace section
/*!
\brief
	Namespace containing all classes that make up the properties interface for the MoveScaleBox class
*/
namespace MoveScaleBoxProperties
{
/*!
\brief
	Property to access the state of the scalable setting for the MoveScaleBox.

	\par Usage:
		- Name: ScalingEnabled
		- Format: "[text]".

	\par Where [Text] is:
		- "True" to indicate the window will be user scalable.
		- "False" to indicate the window will not be scalable by the user.
*/
class ScalingEnabled : public Property
{
public:
	ScalingEnabled() : Property(
		"ScalingEnabled",
		"Property to get/set the state of the scalable setting for the MoveScaleBox.  Value is either \"True\" or \"False\".",
		"True")
	{}

	String	get(const PropertyReceiver* receiver) const;
	void	set(PropertyReceiver* receiver, const String& value);
};


/*!
\brief
	Property to access the state of the movable setting for the MoveScaleBox.
	\par Usage:
		- Name: MovingEnabled
		- Format: "[text]".

	\par Where [Text] is:
		- "True" to indicate the window will be user movable.
		- "False" to indicate the window will not be movable by the user.
*/
class MovingEnabled : public Property
{
public:
	MovingEnabled() : Property(
		"MovingEnabled",
		"Property to get/set tthe state of the movable setting for the MoveScaleBox.  Value is either \"True\" or \"False\".",
		"True")
	{}

	String	get(const PropertyReceiver* receiver) const;
	void	set(PropertyReceiver* receiver, const String& value);
};


/*!
\brief
	Property to access the setting for the scaling border thickness.

	\par Usage:
		- Name: ScalingBorderThickness
		- Format: "[float]".

	\par Where:
		- [float] is the size of the invisible scaling border in screen pixels.
*/
class ScalingBorderThickness : public Property
{
public:
	ScalingBorderThickness() : Property(
		"ScalingBorderThickness",
		"Property to get/set the setting for the scaling border thickness.  Value is a float specifying the border thickness in pixels.",
		"4.000000")
	{}

	String	get(const PropertyReceiver* receiver) const;
	void	set(PropertyReceiver* receiver, const String& value);
};

/*!
\brief
   Property to access the N-S (up-down) scaling cursor image

   \par Usage:
      - Name: NSScalingCursorImage
      - Format: "set:<imageset> image:<imagename>".

*/
class NSScalingCursorImage : public Property
{
public:
   NSScalingCursorImage() : Property(
	   "NSScalingCursorImage",
	   "Property to get/set the N-S (up-down) scaling cursor image for the MoveScaleBox.  Value should be \"set:[imageset name] image:[image name]\".",
	   "")
   {}

   String   get(const PropertyReceiver* receiver) const;
   void   set(PropertyReceiver* receiver, const String& value);
};

/*!
\brief
   Property to access the E-W (left/right) scaling cursor image

   \par Usage:
      - Name: EWScalingCursorImage
      - Format: "set:<imageset> image:<imagename>".

*/
class EWScalingCursorImage : public Property
{
public:
   EWScalingCursorImage() : Property(
	   "EWScalingCursorImage",
	   "Property to get/set the E-W (left-right) scaling cursor image for the MoveScaleBox.  Value should be \"set:[imageset name] image:[image name]\".",
	   "")
   {}

   String   get(const PropertyReceiver* receiver) const;
   void   set(PropertyReceiver* receiver, const String& value);
};

/*!
\brief
   Property to access the NW-SE diagonal scaling cursor image

   \par Usage:
      - Name: NWSEScalingCursorImage
      - Format: "set:<imageset> image:<imagename>".

*/
class NWSEScalingCursorImage : public Property
{
public:
   NWSEScalingCursorImage() : Property(
	   "NWSEScalingCursorImage",
	   "Property to get/set the NW-SE diagonal scaling cursor image for the MoveScaleBox.  Value should be \"set:[imageset name] image:[image name]\".",
	   "")
   {}

   String   get(const PropertyReceiver* receiver) const;
   void   set(PropertyReceiver* receiver, const String& value);
};

/*!
\brief
   Property to access the NE-SW diagonal scaling cursor image

   \par Usage:
      - Name: NESWScalingCursorImage
      - Format: "set:<imageset> image:<imagename>".

*/
class NESWScalingCursorImage : public Property
{
public:
   NESWScalingCursorImage() : Property(
	   "NESWScalingCursorImage",
	   "Property to get/set the NE-SW diagonal scaling cursor image for the MoveScaleBox.  Value should be \"set:[imageset name] image:[image name]\".",
	   "")
   {}

   String   get(const PropertyReceiver* receiver) const;
   void   set(PropertyReceiver* receiver, const String& value);
};

/*!
\brief
   Property to access the moving cursor image

   \par Usage:
      - Name: MovingCursorImage
      - Format: "set:<imageset> image:<imagename>".

*/
class MovingCursorImage : public Property
{
public:
   MovingCursorImage() : Property(
	   "MovingCursorImage",
	   "Property to get/set the moving cursor image for the MoveScaleBox.  Value should be \"set:[imageset name] image:[image name]\".",
	   "")
   {}

   String   get(const PropertyReceiver* receiver) const;
   void   set(PropertyReceiver* receiver, const String& value);
};

} // End of  MoveScaleBoxProperties namespace section

} // End of  CEGUI namespace section


#endif	// end of guard _CEGUIMoveScaleBoxProperties_h_
